==> 1.0.0.tar.gz: android/src/main/java/com/sharetrace/sharetrace_flutter_plugin/SharetraceFlutterPlugin.java <==
package com.sharetrace.sharetrace_flutter_plugin;

import android.app.Application;

import androidx.annotation.NonNull;

import java.util.HashMap;
import java.util.Map;

import cn.net.shoot.sharetracesdk.AppData;
import cn.net.shoot.sharetracesdk.ShareTrace;
import cn.net.shoot.sharetracesdk.ShareTraceInstallListener;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * SharetraceFlutterPlugin
 */
public class SharetraceFlutterPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;

    private static final String KEY_CODE = "code";
    private static final String KEY_MSG = "msg";
    private static final String KEY_PARAMSDATA = "paramsData";
    private static final String KEY_RESUMEPAGE = "resumePage";

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "sharetrace_flutter_plugin");
        channel.setMethodCallHandler(this);
        ShareTrace.init((Application) flutterPluginBinding.getApplicationContext());
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "sharetrace_flutter_plugin");
        channel.setMethodCallHandler(new SharetraceFlutterPlugin());
        ShareTrace.init((Application) registrar.context());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getInstallTrace")) {
            result.success("call getInstallTrace success.");
            ShareTrace.getInstallTrace(new ShareTraceInstallListener() {
                @Override
                public void onInstall(AppData appData) {
                    if (appData == null) {
                        Map<String, String> ret = parseToResult(-1, "Extract data fail.", "", "");
                        response(ret);
                        return;
                    }

                    String paramsData = (appData.paramsData == null) ? "" : appData.paramsData;
                    String resumePage = (appData.resumePage == null) ? "" : appData.resumePage;

                    Map<String, String> ret = parseToResult(200, "Success", paramsData, resumePage);
                    response(ret);
                }

                @Override
                public void onError(int code, String message) {
                    Map<String, String> ret = parseToResult(code, message, "", "");
                    response(ret);
                }
            });
        } else {
            result.notImplemented();
        }
    }

    private void response(Map<String, String> ret) {
        channel.invokeMethod("onInstallResponse", ret);
    }

    private Map<String, String> parseToResult(int code, String msg, String paramsData, String resumePage) {
        Map<String, String> result = new HashMap<>();
        result.put(KEY_CODE, String.valueOf(code));
        result.put(KEY_MSG, msg);
        result.put(KEY_PARAMSDATA, paramsData);
        result.put(KEY_RESUMEPAGE, resumePage);
        return result;
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}

==> 1.0.2.tar.gz: android/src/main/java/com/sharetrace/sharetrace_flutter_plugin/SharetraceFlutterPlugin.java <==
package com.sharetrace.sharetrace_flutter_plugin;

import android.app.Application;

import androidx.annotation.NonNull;

import java.util.HashMap;
import java.util.Map;

import cn.net.shoot.sharetracesdk.AppData;
import cn.net.shoot.sharetracesdk.ShareTrace;
import cn.net.shoot.sharetracesdk.ShareTraceInstallListener;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * SharetraceFlutterPlugin
 */
public class SharetraceFlutterPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private static MethodChannel channel;

    private static final String KEY_CODE = "code";
    private static final String KEY_MSG = "msg";
    private static final String KEY_PARAMSDATA = "paramsData";
    private static final String KEY_RESUMEPAGE = "resumePage";

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "sharetrace_flutter_plugin");
        channel.setMethodCallHandler(this);
        ShareTrace.init((Application) flutterPluginBinding.getApplicationContext());
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        channel = new MethodChannel(registrar.messenger(), "sharetrace_flutter_plugin");
        channel.setMethodCallHandler(new SharetraceFlutterPlugin());
        ShareTrace.init((Application) registrar.context());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getInstallTrace")) {
            result.success("call getInstallTrace success.");
            ShareTrace.getInstallTrace(new ShareTraceInstallListener() {
                @Override
                public void onInstall(AppData appData) {
                    if (appData == null) {
                        Map<String, String> ret = parseToResult(-1, "Extract data fail.", "", "");
                        response(ret);
                        return;
                    }

                    String paramsData = (appData.paramsData == null) ? "" : appData.paramsData;
                    String resumePage = (appData.resumePage == null) ? "" : appData.resumePage;

                    Map<String, String> ret = parseToResult(200, "Success", paramsData, resumePage);
                    response(ret);
                }

                @Override
                public void onError(int code, String message) {
                    Map<String, String> ret = parseToResult(code, message, "", "");
                    response(ret);
                }
            });
        } else {
            result.notImplemented();
        }
    }

    private void response(Map<String, String> ret) {
        if (channel == null) {
            return;
        }
        channel.invokeMethod("onInstallResponse", ret);
    }

    private Map<String, String> parseToResult(int code, String msg, String paramsData, String resumePage) {
        Map<String, String> result = new HashMap<>();
        result.put(KEY_CODE, String.valueOf(code));
        result.put(KEY_MSG, msg);
        result.put(KEY_PARAMSDATA, paramsData);
        result.put(KEY_RESUMEPAGE, resumePage);
        return result;
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
